//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraOptions](index.md)/[allowKuitan](allow-kuitan.md)

# allowKuitan

[common]\
val [allowKuitan](allow-kuitan.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否允许食断
